#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.item import Item
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Outputs(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Outputs
                | 
                | The collection of outputs related to the current activity.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Item)
        self.outputs = com_object

    def add(self, i_output: Item) -> Item:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(Item iOutput) As Item
                | 
                |     This method can be used to assign a given product as an
                |     output
                | 
                |     Parameters:
                | 
                |         iOutput
                |             The output to add 
                | 
                |     Returns:
                |         oProduct The assigned product

        :param Item i_output:
        :rtype: Item
        """
        return Item(self.outputs.Add(i_output.com_object))

    def count_(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Count() As long
                | 
                |     This method returns the no. of products / features that are assigned to a
                |     process as output.
                | 
                |     Returns:
                |         oNbOutputs No. of Outputss that are assigned to the activity.

        :rtype: int
        """
        return self.outputs.Count()

    def item(self, i_index: cat_variant) -> Item:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As Item
                | 
                |     This method can be used to get the associated output
                |     product.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The item identifier (can be the index or the name)
                |             
                | 
                |     Returns:
                |         oProduct The indexed product/MA that is assigned to the process.

        :param cat_variant i_index:
        :rtype: Item
        """
        return Item(self.outputs.Item(i_index))

    def remove(self, i_output: Item) -> Item:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Remove(Item iOutput) As Item
                | 
                |     This method can be used to unassign an output product from a
                |     process
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The product to remove 
                | 
                |     Returns:
                |         oProduct The item

        :param Item i_output:
        :rtype: Item
        """
        return Item(self.outputs.Remove(i_output.com_object))

    def __repr__(self):
        return f'Outputs(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingFactories(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingFactories
                | 
                | Interface to manage manufacturing factories.
                | 
                | Role: CATIAMfgManufacturingFactories has methods to manage manufacturing
                | factories.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_factories = com_object

    def get_manufacturing_resource_factory(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetManufacturingResourceFactory() As AnyObject
                | 
                |     Retrieves the manufacturing resource factory from the given
                |     object.
                | 
                |     Parameters:
                | 
                |         oResourceFactory
                |             The manufacturing resource factory.

        :rtype: AnyObject
        """
        return AnyObject(self.manufacturing_factories.GetManufacturingResourceFactory())

    def __repr__(self):
        return f'ManufacturingFactories(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.general_knowledge_interfaces.expert_rule_base_runtime import ExpertRuleBaseRuntime


class ExpertRuleBase(ExpertRuleBaseRuntime):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     KnowledgeInterfaces.KnowledgeObject
                |                        KnowledgeInterfaces.KnowledgeActivateObject
                |                             KnowledgeInterfaces.Relation
                |                                GenKnowledgeInterfaces.ExpertRuleBaseRuntime
                |                                     ExpertRuleBase
                | 
                | Represents the RuleBase object that can be edited.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.expert_rule_base = com_object

    def volatile_copy(self) -> ExpertRuleBaseRuntime:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func VolatileCopy() As ExpertRuleBaseRuntime
                | 
                |     Copy the persistent rulebase in a unpersistent unchangeable
                |     rulebase.
                | 
                |     Returns:
                |         A volatile copy of the rulebase

        :rtype: ExpertRuleBaseRuntime
        """
        return ExpertRuleBaseRuntime(self.expert_rule_base.VolatileCopy())

    def __repr__(self):
        return f'ExpertRuleBase(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.dnb_human_modeling_interfaces.swk_manikin import SWKManikin
from pycatia.dnb_human_sim_interfaces.human_task import HumanTask


class WorkerActivity(Activity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         WorkerActivity
                | 
                | The object that represents an Worker activity.
                | 
                | Following activity types qualify as worker activities:
                | MoveToPostureActivity
                | WalkActivity (Forward/Backward/SideStep)
                | AutoWalkActivity
                | PickActivity
                | PlaceActivity
                | HumanActivityGroup
                | HumanCallTask
                | CollisionFreeWalk (Forward and Backward)
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.worker_activity = com_object

    @property
    def human_task(self) -> HumanTask:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property HumanTask() As HumanTask (Read Only)
                | 
                |     Returns the parent HumanTask
                | 
                |     Returns:
                |         oHumanTask (see HumanTask for more details)

        :rtype: HumanTask
        """

        return HumanTask(self.worker_activity.HumanTask)

    @property
    def worker_resource(self) -> SWKManikin:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WorkerResource() As SWKManikin (Read Only)
                | 
                |     Returns the Worker-Resource associated with this
                |     worker-activity.
                | 
                |     Returns:
                |         oManikin (see SWKManikin for more details)

        :rtype: SWKManikin
        """

        return SWKManikin(self.worker_activity.WorkerResource)

    def __repr__(self):
        return f'WorkerActivity(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.document import Document
from pycatia.navigator_interfaces.group import Group
from pycatia.product_structure_interfaces.product import Product
from pycatia.smt_interfaces.dmo_offset import DMOOffset
from pycatia.system_interfaces.collection import Collection


class DMOOffsets(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     DMOOffsets
                | 
                | Interface to access a CATIADMOOffsets and compute Offsets
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=DMOOffset)
        self.dmo_offsets = com_object

    def add(
            self,
            i_product_to_offset: Product,
            i_offset1: float,
            i_use_constraints: int,
            i_constraints: tuple,
            i_shape_name: str,
            i_activated_shape: int,
            i_default_shape: int
    ) -> DMOOffset:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(Product iProductToOffset,
                | double iOffset1,
                | long iUseConstraints,
                | CATSafeArrayVariant iConstraints,
                | CATBSTR iShapeName,
                | long iActivatedShape,
                | long iDefaultShape) As DMOOffset
                | 
                |     Creates a new Offset and adds it to the DMOOffsets collection. This
                |     function is deprecated.
                | 
                |     Returns:
                |         The created offset 
                |     Example:
                |         The following example creates an offset newOffset in the Offset
                |         collection.
                | 
                |          Set newOffset = DMOOffsets.Add

        :param Product i_product_to_offset:
        :param float i_offset1:
        :param int i_use_constraints:
        :param tuple i_constraints:
        :param str i_shape_name:
        :param int i_activated_shape:
        :param int i_default_shape:
        :rtype: DMOOffset
        """
        return DMOOffset(
            self.dmo_offsets.Add(
                i_product_to_offset.com_object,
                i_offset1,
                i_use_constraints,
                i_constraints,
                i_shape_name,
                i_activated_shape,
                i_default_shape
            )
        )

    def add_offset_from_vectors(
            self,
            i_product_to_offset: Product,
            i_offset_vectors: tuple,
            i_offset_values: tuple,
            i_shape_name: str,
            i_activated_shape: int,
            i_default_shape: int
    ) -> DMOOffset:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddOffsetFromVectors(Product iProductToOffset,
                | CATSafeArrayVariant iOffsetVectors,
                | CATSafeArrayVariant iOffsetValues,
                | CATBSTR iShapeName,
                | long iActivatedShape,
                | long iDefaultShape) As DMOOffset
                | 
                |     Creates a new Offset from a set of vectors, and adds it to the DMOOffsets
                |     collection. This function is deprecated.
                | 
                |     Returns:
                |         The created offset 
                |     Example:
                |         The following example creates an offset newOffset in the Offset
                |         collection.
                | 
                |          Set newOffset = DMOOffsets.Add

        :param Product i_product_to_offset:
        :param tuple i_offset_vectors:
        :param tuple i_offset_values:
        :param str i_shape_name:
        :param int i_activated_shape:
        :param int i_default_shape:
        :rtype: DMOOffset
        """
        return DMOOffset(
            self.dmo_offsets.AddOffsetFromVectors(
                i_product_to_offset.com_object,
                i_offset_vectors,
                i_offset_values,
                i_shape_name,
                i_activated_shape,
                i_default_shape
            )
        )

    def clean_up(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CleanUp()
                | 
                |     Cleans up.

        :rtype: None
        """
        return self.dmo_offsets.CleanUp()

    def compute_an_offset(
            self,
            group_of_selected_products: Group,
            i_offset: float,
            i_use_constraints: int,
            i_constraints: tuple
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeAnOffset(Group GroupOfSelectedProducts,
                | double iOffset,
                | long iUseConstraints,
                | CATSafeArrayVariant iConstraints) As Document
                | 
                |     Compute a offset on the selected products.
                | 
                |     Parameters:
                | 
                |         GroupOfSelectedProducts
                |             The selected products on which you want to perform the offset.
                |             
                |         iOffset
                |             Offset value. 
                |         iUseConstraints
                |             Do we use normals constraints or not ? 
                |         iConstraints
                |             Constraints array. 
                | 
                |     Returns:
                |         OffsetDocument: Document containing the result.

        :param Group group_of_selected_products:
        :param float i_offset:
        :param int i_use_constraints:
        :param tuple i_constraints:
        :rtype: Document
        """
        return Document(
            self.dmo_offsets.ComputeAnOffset(
                group_of_selected_products.com_object,
                i_offset,
                i_use_constraints,
                i_constraints
            )
        )

    def compute_an_offset_from_vectors(
            self,
            group_of_selected_products: Group,
            i_offset_vectors: tuple,
            i_offset_values: tuple
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeAnOffsetFromVectors(Group
                | GroupOfSelectedProducts,
                | CATSafeArrayVariant iOffsetVectors,
                | CATSafeArrayVariant iOffsetValues) As Document
                | 
                |     Compute an offset on the selected products, according to some
                |     vectors
                | 
                |     Parameters:
                | 
                |         GroupOfSelectedProducts
                |             The selected products on which you want to perform the offset.
                |             
                |         iOffsetVectors
                |             Vectors taken into account for the computation 
                |         iOffsetValues
                |             Offset values. 
                | 
                |     Returns:
                |         OffsetDocument: Document containing the result.

        :param Group group_of_selected_products:
        :param tuple i_offset_vectors:
        :param tuple i_offset_values:
        :rtype: Document
        """
        return Document(
            self.dmo_offsets.ComputeAnOffsetFromVectors(
                group_of_selected_products.com_object,
                i_offset_vectors,
                i_offset_values
            )
        )

    def compute_an_offset_from_vectors_with_a_reference(
            self,
            i_group_of_selected_products: Group,
            i_reference_product: Product,
            i_offset_vectors: tuple,
            i_offset_values: tuple
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeAnOffsetFromVectorsWithAReference(Group
                | iGroupOfSelectedProducts,
                | Product iReferenceProduct,
                | CATSafeArrayVariant iOffsetVectors,
                | CATSafeArrayVariant iOffsetValues) As Document
                | 
                |     Compute an offset on the selected products, according to some vectors and a
                |     reference product.
                | 
                |     Parameters:
                | 
                |         iGroupOfSelectedProducts
                |             The selected products on which you want to perform the offset.
                |             
                |         iReferenceProduct
                |             The reference product. 
                |         iOffsetVectors
                |             Vectors taken into account for the computation 
                |         iOffsetValues
                |             Offset values. 
                | 
                |     Returns:
                |         OffsetDocument: Document containing the result.

        :param Group i_group_of_selected_products:
        :param Product i_reference_product:
        :param tuple i_offset_vectors:
        :param tuple i_offset_values:
        :rtype: Document
        """
        return Document(
            self.dmo_offsets.ComputeAnOffsetFromVectorsWithAReference(
                i_group_of_selected_products.com_object,
                i_reference_product.com_object,
                i_offset_vectors,
                i_offset_values
            )
        )

    def compute_an_offset_with_a_reference(
            self,
            i_group_of_selected_products: Group,
            i_reference_product: Product,
            i_offset: float,
            i_use_constraints: int,
            i_constraints: tuple
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeAnOffsetWithAReference(Group
                | iGroupOfSelectedProducts,
                | Product iReferenceProduct,
                | double iOffset,
                | long iUseConstraints,
                | CATSafeArrayVariant iConstraints) As Document
                | 
                |     Compute an offset on the selected products, according to a reference
                |     product.
                | 
                |     Parameters:
                | 
                |         iGroupOfSelectedProducts
                |             The selected products on which you want to perform the offset.
                |             
                |         iReferenceProduct
                |             The reference product. 
                |         iOffset
                |             Offset value. 
                |         iUseConstraints
                |             Do we use normals constraints or not ? 
                |         iConstraints
                |             Constraints array. 
                | 
                |     Returns:
                |         OffsetDocument: Document containing the result.

        :param Group i_group_of_selected_products:
        :param Product i_reference_product:
        :param float i_offset:
        :param int i_use_constraints:
        :param tuple i_constraints:
        :rtype: Document
        """
        return Document(
            self.dmo_offsets.ComputeAnOffsetWithAReference(
                i_group_of_selected_products.com_object,
                i_reference_product.com_object,
                i_offset,
                i_use_constraints,
                i_constraints
            )
        )

    def offset_shape_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func OffsetShapeName() As CATBSTR
                | 
                |     Returns the name of the associated shape.

        :rtype: str
        """
        return self.dmo_offsets.OffsetShapeName()

    def __repr__(self):
        return f'DmoOffsets(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.int_param import IntParam
from pycatia.part_interfaces.linear_repartition import LinearRepartition
from pycatia.part_interfaces.pattern import Pattern


class RectPattern(Pattern):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.TransformationShape
                |                             PartInterfaces.Pattern
                |                                 RectPattern
                | 
                | Represents the rectangular pattern.
                | The shape is copied along two directions. Two linear repartitions control the
                | shape copy.
                | 
                | See also:
                |     LinearRepartition
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.rect_pattern = com_object

    @property
    def first_direction_repartition(self) -> LinearRepartition:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstDirectionRepartition() As LinearRepartition (Read
                | Only)
                | 
                |     Returns the linear repartition along the first direction.
                | 
                |     Example:
                |         The following example returns in repart1 the first linear repartition
                |         of the rectangular pattern firstPattern:
                | 
                |          Set repart1 = firstPattern.FirstDirectionRepartition

        :rtype: LinearRepartition
        """

        return LinearRepartition(self.rect_pattern.FirstDirectionRepartition)

    @property
    def first_direction_row(self) -> IntParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstDirectionRow() As IntParam (Read Only)
                | 
                |     Returns the position of the shape to be copied along the first linear
                |     direction.
                | 
                |     Example:
                |         The following example returns in FirstDirPos the position of the shape
                |         to be copied along the first linear direction in the rectangular pattern
                |         firstPattern:
                | 
                |          Set FirstDirPos = firstPattern.FirstDirectionRow

        :rtype: IntParam
        """

        return IntParam(self.rect_pattern.FirstDirectionRow)

    @property
    def first_orientation(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstOrientation() As boolean
                | 
                |     Returns or sets whether the pattern is built towards the first direction
                |     orientation.
                |     True if the pattern is built towards the first direction
                |     orientation.
                | 
                |     Example:
                |         The following example returns in aligned1 whether the rectangular
                |         pattern firstPattern is built towards the first direction orientation, and then
                |         sets its to True:
                | 
                |          Set aligned1 = firstPattern.FirstOrientation
                |          firstPattern.FirstOrientation = True

        :rtype: bool
        """

        return self.rect_pattern.FirstOrientation

    @first_orientation.setter
    def first_orientation(self, value: bool):
        """
        :param bool value:
        """

        self.rect_pattern.FirstOrientation = value

    @property
    def first_rectangular_pattern_parameters(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstRectangularPatternParameters() As
                | CatRectangularPatternParameters
                | 
                |     Returns or sets the rectangular pattern parameters required to define the
                |     pattern. These parameters are used when reading the CATIALinearRepartition
                |     properties.
                | 
                |     Example:
                |         The following example returns in parameters the rectangular pattern
                |         parameters of the firstPattern rectangular pattern, and then sets it to
                |         catUnequalSpacing, so that the unqual spacing will be defined in first
                |         direction:
                | 
                |          Set parameters = firstPattern.FirstCircularPatternParameters
                |          Set firstPattern.FirstCircularPatternParameters = catUnequalSpacing

        :return: enum cat_rectangular_pattern_parameters
        :rtype: int
        """

        return self.rect_pattern.FirstRectangularPatternParameters

    @first_rectangular_pattern_parameters.setter
    def first_rectangular_pattern_parameters(self, value: int):
        """
        :param int value: enum cat_rectangular_pattern_parameters
        """

        self.rect_pattern.FirstRectangularPatternParameters = value

    @property
    def second_direction_repartition(self) -> LinearRepartition:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondDirectionRepartition() As LinearRepartition (Read
                | Only)
                | 
                |     Returns the linear repartition along the second direction.
                | 
                |     Example:
                |         The following example returns in repart2 the second linear repartition
                |         of the rectangular pattern firstPattern:
                | 
                |          Set repart2 = firstPattern.SecondDirectionRepartition

        :rtype: LinearRepartition
        """

        return LinearRepartition(self.rect_pattern.SecondDirectionRepartition)

    @property
    def second_direction_row(self) -> IntParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondDirectionRow() As IntParam (Read Only)
                | 
                |     Returns the position of the shape to be copied along the second linear
                |     direction.
                | 
                |     Example:
                |         The following example returns in SecondDirPos the position of the shape
                |         to be copied along the second linear direction in the rectangular pattern
                |         firstPattern:
                | 
                |          Set SecondDirPos = firstPattern.SecondDirectionRow

        :rtype: IntParam
        """

        return IntParam(self.rect_pattern.SecondDirectionRow)

    @property
    def second_orientation(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondOrientation() As boolean
                | 
                |     Returns or sets whether the pattern is built towards the second direction
                |     orientation.
                |     True if the pattern is built towards the second direction
                |     orientation.
                | 
                |     Example:
                |         The following example returns in aligned2 whether the rectangular
                |         pattern firstPattern is built towards the second direction orientation, and
                |         then sets its to False, meaning the pattern is built in the opposite
                |         direction:
                | 
                |          Set aligned2 = firstPattern.SecondOrientation
                |          firstPattern.SecondOrientation = False

        :rtype: bool
        """

        return self.rect_pattern.SecondOrientation

    @second_orientation.setter
    def second_orientation(self, value: bool):
        """
        :param bool value:
        """

        self.rect_pattern.SecondOrientation = value

    @property
    def second_rectangular_pattern_parameters(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondRectangularPatternParameters() As
                | CatRectangularPatternParameters
                | 
                |     Returns or sets the rectangular pattern parameters required to define the
                |     pattern. These parameters are used when reading the CATIALinearRepartition
                |     properties.
                | 
                |     Example:
                |         The following example returns in parameters the rectangular pattern
                |         parameters of the secondPattern rectangular pattern, and then sets it to
                |         catUnequalSpacing, so that the unqual spacing will be defined in second
                |         direction:
                | 
                |          Set parameters = secondPattern.SecondCircularPatternParameters
                |          Set secondPattern.SecondCircularPatternParameters = catUnequalSpacing

        :return: enum cat_rectangular_pattern_parameters
        :rtype: int
        """

        return self.rect_pattern.SecondRectangularPatternParameters

    @second_rectangular_pattern_parameters.setter
    def second_rectangular_pattern_parameters(self, value: int):
        """
        :param int value: enum cat_rectangular_pattern_parameters
        """

        self.rect_pattern.SecondRectangularPatternParameters = value

    def get_first_direction(self, io_first_direction: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetFirstDirection(CATSafeArrayVariant
                | ioFirstDirection)
                | 
                |     Returns the first repartition direction. The first repartition direction is
                |     returned as an array containing the direction vector components. Assume this
                |     array is o1stDirRep. It contains:
                | 
                |     o1stDirRep[0],o1stDirRep[1],o1stDirRep[2]
                |         The X, Y, and Z direction vector components 
                | 
                |     Example:
                |         The following example returns in FirstDir the first repartition
                |         direction vector components of the rectangular pattern firstPattern and saves
                |         them in variables:
                | 
                |          Dim FirstDir()
                |          Call firstPattern.GetFirstDirection(FirstDir)
                |          x = FirstDir(0)
                |          y = FirstDir(1)
                |          z = FirstDir(2)

        :param tuple io_first_direction:
        :rtype: None
        """
        return self.rect_pattern.GetFirstDirection(io_first_direction)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_first_direction'
        # # vba_code = """
        # # Public Function get_first_direction(rect_pattern)
        # #     Dim ioFirstDirection (2)
        # #     rect_pattern.GetFirstDirection ioFirstDirection
        # #     get_first_direction = ioFirstDirection
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_second_direction(self, io_second_direction: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetSecondDirection(CATSafeArrayVariant
                | ioSecondDirection)
                | 
                |     Returns the second repartition direction. The second repartition direction
                |     is returned as an array containing the direction vector components. Assume this
                |     array is o2ndDirRep. It contains:
                | 
                |     o2ndDirRep[0],o2ndDirRep[1],o2ndDirRep[2]
                |         The X, Y, and Z direction vector components 
                | 
                |     Example:
                |         The following example returns in SecondDir the second repartition
                |         direction vector components of the rectangular pattern firstPattern and saves
                |         them in variables:
                | 
                |          Call firstPattern.GetSecondDirection(SecondDir)
                |          x = SecondDir[0]
                |          y = SecondDir[1]
                |          z = SecondDir[2]

        :param tuple io_second_direction:
        :rtype: None
        """
        return self.rect_pattern.GetSecondDirection(io_second_direction)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_second_direction'
        # # vba_code = """
        # # Public Function get_second_direction(rect_pattern)
        # #     Dim ioSecondDirection (2)
        # #     rect_pattern.GetSecondDirection ioSecondDirection
        # #     get_second_direction = ioSecondDirection
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_first_direction(self, i_first_direction: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetFirstDirection(Reference iFirstDirection)
                | 
                |     Sets the first repartition direction.
                | 
                |     Parameters:
                | 
                |         iFirstDirection
                |             The first repartition direction. It is passed as a
                |             
                | 
                |         Reference and can be valuated with a reference to a line or an
                |         edge.
                |         The following Boundary objects are supported: PlanarFace,
                |         RectilinearTriDimFeatEdge and RectilinearBiDimFeatEdge.
                |         
                | 
                | Example:
                |     The following example sets the first repartition direction of the
                |     rectangular pattern firstPattern with the refToLine1 reference
                |     :
                | 
                |      firstPattern.SetFirstDirection refToLine1

        :param Reference i_first_direction:
        :rtype: None
        """
        return self.rect_pattern.SetFirstDirection(i_first_direction.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_first_direction'
        # # vba_code = """
        # # Public Function set_first_direction(rect_pattern)
        # #     Dim iFirstDirection (2)
        # #     rect_pattern.SetFirstDirection iFirstDirection
        # #     set_first_direction = iFirstDirection
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_instance_spacing(self, i_instance_number: int, i_spacing: float, i_direction: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetInstanceSpacing(long iInstanceNumber,
                | double iSpacing,
                | long iDirection)
                | 
                |     Sets the InstanceSpacing.
                | 
                |     Parameters:
                | 
                |         iInstanceNumber
                |             The Instance Number 
                |         iSpacing
                |             The Spacing 
                |         iDirection
                |             The Instance direction 
                | 
                |     Example:
                |         The following example sets the InstanceSpacing in a direction for
                |         unequal spacing

        :param int i_instance_number:
        :param float i_spacing:
        :param int i_direction:
        :rtype: None
        """
        return self.rect_pattern.SetInstanceSpacing(i_instance_number, i_spacing, i_direction)

    def set_second_direction(self, i_second_direction: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetSecondDirection(Reference iSecondDirection)
                | 
                |     Sets the second repartition direction.
                | 
                |     Parameters:
                | 
                |         iSecondDirection
                |             The second repartition direction. It is passed as a
                |             
                | 
                |         Reference and can be valuated with a reference to a line or an
                |         edge.
                |         The following Boundary objects are supported: PlanarFace,
                |         RectilinearTriDimFeatEdge and RectilinearBiDimFeatEdge.
                |         
                | 
                | Example:
                |     The following example sets the second repartition direction of the
                |     rectangular pattern firstPattern with the refToLine2 reference
                |     :
                | 
                |      firstPattern.SetSecondDirection refToLine2

        :param Reference i_second_direction:
        :rtype: None
        """
        return self.rect_pattern.SetSecondDirection(i_second_direction.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_second_direction'
        # # vba_code = """
        # # Public Function set_second_direction(rect_pattern)
        # #     Dim iSecondDirection (2)
        # #     rect_pattern.SetSecondDirection iSecondDirection
        # #     set_second_direction = iSecondDirection
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_unequal_instance_number(self, i_instance_number: int, i_direction: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetUnequalInstanceNumber(long iInstanceNumber,
                | long iDirection)
                | 
                |     Sets the Instance Number.
                | 
                |     Parameters:
                | 
                |         iInstanceNumber
                |             The Instance Number 
                |         iDirection
                |             The Instance direction 
                | 
                |     Example:
                |         The following example modifies the instance number for unequal spacing

        :param int i_instance_number:
        :param int i_direction:
        :rtype: None
        """
        return self.rect_pattern.SetUnequalInstanceNumber(i_instance_number, i_direction)

    def __repr__(self):
        return f'RectPattern(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_app_multi_image_master import SchAppMultiImageMaster
from pycatia.in_interfaces.document import Document
from pycatia.system_interfaces.any_object import AnyObject


class SchAppMultiImage(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppMultiImage
                | 
                | Interface to manage the image object in the Multi-Image-Object
                | concept.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_multi_image = com_object

    def app_get_master_document(self, o_document: Document, o_document_name: str, o_symbolic_link_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppGetMasterDocument(Document oDocument,
                | CATBSTR oDocumentName,
                | CATBSTR oSymbolicLinkName)
                | 
                |     Get the document where the master of this image object
                |     resides.
                | 
                |     Parameters:
                | 
                |         oDocument
                |             Pointer to the document. 
                |         oDocumentName
                |             Name of the document containing the master. 
                |         oSymbolicLinkName
                |             Name of the symbolic link. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppMultiImage
                |          Dim objDoc As Document
                |          Dim strDocName As String
                |          Dim strLinkName As String
                |           ...
                |          objThisIntf.AppGetMasterDocument
                |          objDoc,strDocName,strLinkName

        :param Document o_document:
        :param str o_document_name:
        :param str o_symbolic_link_name:
        :rtype: None
        """
        return self.sch_app_multi_image.AppGetMasterDocument(
            o_document.com_object,
            o_document_name,
            o_symbolic_link_name
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_get_master_document'
        # # vba_code = """
        # # Public Function app_get_master_document(sch_app_multi_image)
        # #     Dim oDocument (2)
        # #     sch_app_multi_image.AppGetMasterDocument oDocument
        # #     app_get_master_document = oDocument
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_get_master_object(self) -> SchAppMultiImageMaster:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AppGetMasterObject() As SchAppMultiImageMaster
                | 
                |     Get the master object of this image.
                | 
                |     Parameters:
                | 
                |         oMasterImage
                |             Pointer to the master object. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppMultiImage
                |          Dim objMaster As SchMultiImageMaster
                |           ...
                |          Set objMaster = objThisIntf.AppGetMasterObject

        :rtype: SchAppMultiImageMaster
        """
        return SchAppMultiImageMaster(self.sch_app_multi_image.AppGetMasterObject())

    def app_is_up_to_date(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppIsUpToDate(CatSchIDLMultiImageStatus oStatus)
                | 
                |     Check if the image object is up-to-date.
                | 
                |     Parameters:
                | 
                |         oStatus
                |             Status of the image object. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppMultiImage
                |           ...
                |          objThisIntf.AppIsUpToDate
                |          CatSchIDLMultiImageStatus_Enum

        :return: enum cat_sch_idl_multi_image_status
        :rtype: int
        """
        return self.sch_app_multi_image.AppIsUpToDate()

    def app_update(self, i_master_image: SchAppMultiImageMaster, o_image: 'SchAppMultiImage') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppUpdate(SchAppMultiImageMaster iMasterImage,
                | SchAppMultiImage oImage)
                | 
                |     Update the image object.
                | 
                |     Parameters:
                | 
                |         iMasterImage
                |             This is an optional input. Not NULL - the application has a handle
                |             on the master to update this image (for example in DSA application, the
                |             application will make sure the ID of this image is the same as the input
                |             master). NULL - the application will find the master based on the specific way
                |             it models the MIO concept. Sample case: the application will make sure the ID
                |             of this image is the same as the input master. 
                |         oImage
                |             Pointer to a new image object created if existing image object has
                |             to be replaced during the update process. This pointer is NULL if the image
                |             object is not replaced. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchAppMultiImage
                |          Dim objMaster As SchAppMultiImageMaster
                |          Dim objNewImage As SchAppMultiImage
                |           ...
                |          objThisIntf.AppUpdate objMaster,objNewImage

        :param SchAppMultiImageMaster i_master_image:
        :param SchAppMultiImage o_image:
        :rtype: None
        """
        return self.sch_app_multi_image.AppUpdate(i_master_image.com_object, o_image.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_update'
        # # vba_code = """
        # # Public Function app_update(sch_app_multi_image)
        # #     Dim iMasterImage (2)
        # #     sch_app_multi_image.AppUpdate iMasterImage
        # #     app_update = iMasterImage
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchAppMultiImage(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_plant_ship_interfaces.psp_list_of_bstrs import PSPListOfBSTRs
from pycatia.cat_plant_ship_interfaces.psp_list_of_objects import PSPListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class PSPFunctional(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspFunctional
                | 
                | Represents Plant Ship functional object.
                | Role: To access Plant Ship Functional object information.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_functional = com_object

    @property
    def catalog_part_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CatalogPartName() As CATBSTR (Read Only)
                | 
                |     Returns catalog part name of physical object that realizes this
                |     function.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspFunctional
                |          Dim strVar1 As CATBSTR
                |           ...
                |          Set strVar1 = objThisIntf.CatalogPartName

        :rtype: str
        """

        return self.psp_functional.CatalogPartName

    @property
    def function_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FunctionStatus() As CatPspIDLFunctionStatus (Read
                | Only)
                | 
                |     Returns function object status.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspPhysical
                |          Dim objArg1 As CatPspIDLFunctionStatus
                |           ...
                |          objArg1 = objThisIntf.FunctionStatus

        :return: enum cat_psp_idl_function_status
        :rtype: int
        """

        return self.psp_functional.FunctionStatus

    @property
    def part_catalog_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PartCatalogName() As CATBSTR (Read Only)
                | 
                |     Returns Part catalog name of physical object that realizes this
                |     function.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspFunctional
                |          Dim strVar1 As CATBSTR
                |           ...
                |          strVar1 = objThisIntf.PartCatalogName

        :rtype: str
        """

        return self.psp_functional.PartCatalogName

    @property
    def part_number(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PartNumber() As CATBSTR (Read Only)
                | 
                |     Returns part number of physical object that realizes this
                |     function.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspFunctional
                |          Dim strVar1 As CATBSTR
                |           ...
                |          strVar1 = objThisIntf.PartNumber

        :rtype: str
        """

        return self.psp_functional.PartNumber

    @property
    def part_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PartType() As CATBSTR (Read Only)
                | 
                |     Returns the part type of physical object that realizes this
                |     function.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspFunctional
                |          Dim strVar1 As CATBSTR
                |           ...
                |          strVar1 = objThisIntf.PartType

        :rtype: str
        """

        return self.psp_functional.PartType

    @property
    def physicals(self) -> PSPListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Physicals() As PspListOfObjects (Read Only)
                | 
                |     Returns a list of all associated physical objects.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspFunctional
                |          Dim objArg1 As PspListOfObjects
                |           ...
                |          Set objArg1 = objThisIntf.Physicals

        :rtype: PSPListOfObjects
        """

        return PSPListOfObjects(self.psp_functional.Physicals)

    @property
    def standard(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Standard() As CATBSTR (Read Only)
                | 
                |     Return Standard.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspFunctional
                |          Dim strVar1 As CATBSTR
                |           ...
                |          strVar1 = objThisIntf.Standard

        :rtype: str
        """

        return self.psp_functional.Standard

    def get_compatible_part_types(self, iu_standard: str) -> PSPListOfBSTRs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCompatiblePartTypes(CATBSTR iuStandard) As
                | PspListOfBSTRs
                | 
                |     Retrieves a list of all physical part types that are compatible with this
                |     function.
                | 
                |     Parameters:
                | 
                |         iuStandard
                |             Standard name 
                | 
                |     Returns:
                |         List of Compatible Part Types.
                |
                |     Example:
                |
                |          Dim objThisIntf As PspFunctional  
                |          Dim strVar1 As CATBSTR
                |          Dim objArg2 As PspListOfBSTRs
                |          
                |           ...
                |          Set objArg1 = objThisIntf.GetCompatiblePartTypes   (strVar1)

        :param str iu_standard:
        :rtype: PSPListOfBSTRs
        """
        return PSPListOfBSTRs(self.psp_functional.GetCompatiblePartTypes(iu_standard))

    def is_ok_to_integrate(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsOKToIntegrate() As boolean
                | 
                |     Check it is OK to integrate (realize) this function with a physical
                |     part.
                | 
                |     Returns:
                |         TRUE if ok to be integrated
                |
                |     Example:
                |
                |          Dim objThisIntf As PspFunctional  
                |          Dim objArg1 As boolean  
                |           ...
                |          objArg1 = objThisIntf.IsOKToIntegrate

        :rtype: bool
        """
        return self.psp_functional.IsOKToIntegrate()

    def is_realized(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsRealized() As boolean
                | 
                |     Checks if the Function object is realized or not.
                | 
                |     Returns:
                |         TRUE if the object is Realized
                |
                |     Example:
                |
                |          Dim objThisIntf As PspFunctional  
                |          Dim objArg1 As boolean  
                |           ...
                |          objArg1 = objThisIntf.IsRealized

        :rtype: bool
        """
        return self.psp_functional.IsRealized()

    def is_spec_driven(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsSpecDriven() As boolean
                | 
                |     Checks if the functional object is specification driven or
                |     not.
                | 
                |     Returns:
                |         TRUE if this object is specification driven.
                |
                |     Example:
                |
                |          Dim objThisIntf As PspFunctional  
                |          Dim objArg1 As boolean  
                |           ...
                |          objArg1 = objThisIntf.IsSpecDriven

        :rtype: bool
        """
        return self.psp_functional.IsSpecDriven()

    def list_compatible_part_numbers(
            self,
            iu_part_type: str,
            iu_standard: str,
            iu_catalog_name: str,
            o_l_part_types: PSPListOfBSTRs,
            o_l_catalog_part_names: PSPListOfBSTRs
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ListCompatiblePartNumbers(CATBSTR iuPartType,
                | CATBSTR iuStandard,
                | CATBSTR iuCatalogName,
                | PspListOfBSTRs oLPartTypes,
                | PspListOfBSTRs oLCatalogPartNames)
                | 
                |     Retrieves a list of compatible Part numbers and part
                |     types.
                | 
                |     Parameters:
                | 
                |         iuPartType
                |             part type 
                |         iuStandard
                |             Standard name 
                |         iuCatalogName
                |             catalog name 
                |         oLPartTypes
                |             a list of part types 
                |         oLCatalogPartNames
                |             List of catalog part names 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspFunctional
                |          Dim strVar1 As CATBSTR
                |          Dim strVar2 As CATBSTR
                |          Dim strVar3 As CATBSTR
                |          Dim objArg4 As PspListOfBSTRs
                |          Dim objArg5 As PspListOfBSTRs
                |          
                |          ..
                |          ..
                |          objThisIntf.ListCompatiblePartNumbers
                |          strVar1,strVar2,strVar3,objArg4,objArg5

        :param str iu_part_type:
        :param str iu_standard:
        :param str iu_catalog_name:
        :param PSPListOfBSTRs o_l_part_types:
        :param PSPListOfBSTRs o_l_catalog_part_names:
        :rtype: None
        """
        return self.psp_functional.ListCompatiblePartNumbers(
            iu_part_type,
            iu_standard,
            iu_catalog_name,
            o_l_part_types.com_object,
            o_l_catalog_part_names.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'list_compatible_part_numbers'
        # # vba_code = """
        # # Public Function list_compatible_part_numbers(psp_functional)
        # #     Dim iuPartType (2)
        # #     psp_functional.ListCompatiblePartNumbers iuPartType
        # #     list_compatible_part_numbers = iuPartType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'PSPFunctional(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class MHILoadParameters(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MHILoadParameters
                | 
                | Interface representing a means to set information that is needed for the load
                | and also to retrieve this information on the loaded document.
                | Note: All the IDs in the Get and Set methods defined in this inteface deal with
                | Object ID (attribute name: oid), not the Object UUID (attribute name:
                | objectuuid)
                | 
                | Access to this interface is provided via DNBIAMHIOpenAccess and
                | DNBIAMHISaveAccess. Applications and CAA partners should NOT implement this
                | interface.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.mhi_load_parameters = com_object

    def get_branch_ids(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetBranchIDs() As CATSafeArrayVariant
                | 
                |     Gets the "subcompitem" IDs (oid) of the Branch. Branch is a list of parents
                |     of the selected object. Please refer to the following PES for details on
                |     Branch. "PES_DELMIA_V5R17_Manufacturing Hub Infrastructure_Manufacturing Hub
                |     Integration_R17MHI031_ExposeLoadSave.doc"
                | 
                |     Example:
                | 
                |            For the following structure, if PWP is the object loaded,
                |
                |             PV
                |              |_PP
                |                 |_WP
                |                    |_PWP
                |                        |_OP1
                |                        |_OP2
                |
                |          the branch is the "subcompitem" ID of PWP, the "subcompitem" ID of WP
                |          and 
                |          the "subcompitem" ID of PP. 
                |          
                |         Note: The list will be filled in that order.
                |
                |     Parameters:
                | 
                |         oListBranchIDs
                |             [out] List of IDs of the Branch in the order mentioned above
                |
                |     Returns:
                |         S_OK in one/more IDs returned S_FALSE if empty output list

        :rtype: tuple
        """
        return self.mhi_load_parameters.GetBranchIDs()

    def get_detailing_id(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDetailingID() As CATBSTR
                | 
                |     Gets the ID (oid) of the loaded detailing
                | 
                |     Parameters:
                | 
                |         oDetailingID
                |             [inout] ID of the loaded detailing 
                | 
                |     Returns:
                |         S_OK if non-empty string returned S_FALSE if empty string

        :rtype: str
        """
        return self.mhi_load_parameters.GetDetailingID()

    def get_process_tree_id(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetProcessTreeID() As CATBSTR
                | 
                |     Gets the "subcompitem" ID (oid) of the process tree selected for the load
                |     For the topmost node in the tree, since no "subcompitem" ID is available, the
                |     "ergocompbase" ID is supplied as the BOM
                | 
                |     Parameters:
                | 
                |         oProcessTreeID
                |             [inout] ID of the select process tree 
                | 
                |     Returns:
                |         S_OK if non-empty string returned S_FALSE if empty string

        :rtype: str
        """
        return self.mhi_load_parameters.GetProcessTreeID()

    def get_product_bom_id(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetProductBOMID() As CATBSTR
                | 
                |     Gets the "subcompitem" ID (oid) of the product BOM selected for the load
                |     For the topmost node in the tree, since no "subcompitem" ID is available, the
                |     "ergocompbase" ID is supplied as the BOM
                | 
                |     Parameters:
                | 
                |         oProductBOMID
                |             [inout] ID of the select product BOM 
                | 
                |     Returns:
                |         S_OK if non-empty string returned S_FALSE if empty string

        :rtype: str
        """
        return self.mhi_load_parameters.GetProductBOMID()

    def get_resource_tree_id(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetResourceTreeID() As CATBSTR
                | 
                |     Gets the "subcompitem" ID (oid) of the resource tree selected for the load
                |     For the topmost node in the tree, since no "subcompitem" ID is available, the
                |     "ergocompbase" ID is supplied as the BOM
                | 
                |     Parameters:
                | 
                |         oResourceTreeID
                |             [inout] ID of the select resource tree 
                | 
                |     Returns:
                |         S_OK if non-empty string returned S_FALSE if empty string

        :rtype: str
        """
        return self.mhi_load_parameters.GetResourceTreeID()

    def get_selected_object_id(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSelectedObjectID() As CATBSTR
                | 
                |     Gets the "ergocompbase" ID (oid) of the selected object (object used to
                |     start the load)
                | 
                |     Parameters:
                | 
                |         oSelectedObjectID
                |             [inout] ID of the selected object 
                | 
                |     Returns:
                |         S_OK if non-empty string returned S_FALSE if empty string

        :rtype: str
        """
        return self.mhi_load_parameters.GetSelectedObjectID()

    def set_branch_i_ds(self, i_list_branch_i_ds: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetBranchIDs(CATSafeArrayVariant iListBranchIDs)
                | 
                |     Sets the "subcompitem" IDs (oid) of the Branch. Branch is a list of parents
                |     of the selected object. Please refer to the following PES for details on
                |     Branch. "PES_DELMIA_V5R17_Manufacturing Hub Infrastructure_Manufacturing Hub
                |     Integration_R17MHI031_ExposeLoadSave.doc"
                | 
                |     Example:
                | 
                |            For the following structure, if PWP is the object to be loaded,
                |
                |             PV
                |              |_PP
                |                 |_WP
                |                    |_PWP
                |                        |_OP1
                |                        |_OP2
                |
                |          the branch is the "subcompitem" ID of PWP, the "subcompitem" ID of WP
                |          and the "subcompitem" ID of PP.
                |          
                |         Note: The list MUST be filled in that order.
                |
                |     Parameters:
                | 
                |         iListBranchIDs
                |             [in] List of IDs of the Branch in the order mentioned above
                |
                |     Returns:
                |         S_OK in all cases

        :param tuple i_list_branch_i_ds:
        :rtype: None
        """
        return self.mhi_load_parameters.SetBranchIDs(i_list_branch_i_ds)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_branch_i_ds'
        # # vba_code = """
        # # Public Function set_branch_i_ds(mhi_load_parameters)
        # #     Dim iListBranchIDs (2)
        # #     mhi_load_parameters.SetBranchIDs iListBranchIDs
        # #     set_branch_i_ds = iListBranchIDs
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_detailing_id(self, i_detailing_id: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDetailingID(CATBSTR iDetailingID)
                | 
                |     Sets the ID (oid) of detailing to be loaded
                | 
                |     Parameters:
                | 
                |         iDetailingID
                |             [in] ID of the detailing 
                | 
                |     Returns:
                |         S_OK in all cases

        :param str i_detailing_id:
        :rtype: None
        """
        return self.mhi_load_parameters.SetDetailingID(i_detailing_id)

    def set_filters(self, i_filters: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetFilters(CATBSTR iFilters)
                | 
                |     Specifies the filters to be applied while loading the project. The filters
                |     can be specified either in the new way (V5R18 onwards) or the old
                |     way.
                | 
                |      New Way of Filtering:
                |      
                |      In the new way of filtering different filters can be set for
                |      P,P,R
                |      by specifiying different filter sets for each area and also a global
                |      filter set.
                |
                |      Old way of Filtering:
                | 
                |      In case of P,P,R filters, either
                |       (a) A Filter string can be supplied OR
                |       (b) A Calculation Model ID can be supplied
                |      Note: Calculation Model filters MUST only be supplied through their IDs.
                |
                |      In case of extended filters, either
                |       (a) A Filter string can be supplied OR
                |       (b) A Calculation Model ID can be supplied OR
                |       (c) Both string AND Model ID can be supplied (Combined effectivity
                |       case)
                |      Note: Calculation Model filters MUST only be supplied through their IDs.
                |
                |      In case of effectivity filter mode, one of the following rules can be
                |      supplied
                |       (a) Give the objects whose begin & end dates contains the begin & end
                |       date filters values.
                |           The rule value is 1.
                |       (b) Give the object whose begin & end dates are with in the begin & end
                |       dates filter values.
                |           The rule value is 2.
                |       (c) Give the object whose begin date value is lesser than the begin date
                |       filter value &
                |           the end date value on the object is contained with in the begin & end
                |           date filter values.
                |           The rule value is 4.
                |       (d) Give the object whose begin date value is contained with in the begin
                |       & end date filter values &
                |           the end date value on the object is greater than the end date filter
                |           value.
                |           The rule value is 8.
                |       (e) Give the object whose begin & end dates exactly match with that of
                |       the begin & end date filter values
                |           The rule value is 16.
                |      Note: Combination of the above said rules can also be
                |      used.
                |           For example: If the user wants the combination of rule a & c, then
                |           the value of 5 should be passed
                |      Note: If the user has not specified any value for this filter, then a
                |      default value of 31 (combination of all rules) will be
                |      used.
                |
                |     Parameters:
                | 
                |         iFilters
                |             [in]
                | 
                |               The filters to be set. 
                |               This is a list of values separated by XML type tags. User Should
                |               specify tags only from one of the below 
                |               set of tags applicable for new and old
                |               filtering.
                | 
                |               The following tags are supported for New way of
                |               Filtering:
                | 
                |                  <GlobalFilterSetName>Global Filter
                |                  Name</GlobalFilterSetName>
                |                  <ProductFilterSetName>Product Filter
                |                  Name</ProductFilterSetName>
                |                  <ProcessFilterSetName>Process Filter
                |                  Name</ProcessFilterSetName>
                |                  <ResourceFilterSetName>Process Filter
                |                  Name</ResourceFilterSetName>   
                |                  <ModStatementFilterID>Filter
                |                  Value</ModStatementFilterID>
                |                  <ProductFilterByCO>Filter
                |                  Value</ProductFilterByCO>
                |                  <PreFilter>Filter Value</PreFilter>
                |                  <PostFilter>Filter Value</PostFilter>
                |                  <PrePostFilter>Filter Value</PrePostFilter>
                |                  <PlanningStateOwnerFilterID>ID of Planning
                |                  State</PlanningStateOwnerFilterID>
                |                  <PlanningStateOtherFilterID>ID of Planning
                |                  State</PlanningStateOtherFilterID>
                |                  <ApplyImplicitFilter>TRUE or
                |                  FALSE</ApplyImplicitFilter>
                |
                |               The following tags are supported for Old way of
                |               Filtering:
                | 
                |                  <ProcessFilter>Filter Value</ProcessFilter>
                |                  <ProcessFilterCalcModelID>ID of Calculation Model
                |                  Filter</ProcessFilterCalcModelID>  
                |                  <ProductFilter>Filter Value</ProductFilter>
                |                  <ProductFilterCalcModelID>ID of Calculation Model
                |                  Filter</ProductFilterCalcModelID>
                |                  <ResourceFilter>Filter Value</ResourceFilter>
                |                  <ResourceFilterCalcModelID>ID of Calculation Model
                |                  Filter</ResourceFilterCalcModelID>
                |                  <StartDateEffectivityFilter>Filter
                |                  Value</StartDateEffectivityFilter>
                |                  <EndDateEffectivityFilter>Filter
                |                  Value</EndDateEffectivityFilter>
                |                  <EffectivityFilterMode>Filter
                |                  Value</EffectivityFilterMode>
                |                  <LineNumberFilter>Filter
                |                  Value</LineNumberFilter>
                |                  <LabelFilter>Filter Value</LabelFilter>
                |                  <ModStatementFilterID>Filter
                |                  Value</ModStatementFilterID>
                |                  <PlanningStateOwnerFilterID>ID of Planning
                |                  State</PlanningStateOwnerFilterID>
                |                  <PlanningStateOtherFilterID>ID of Planning
                |                  State</PlanningStateOtherFilterID>
                |                  <ApplyImplicitFilter>TRUE or
                |                  FALSE</ApplyImplicitFilter>
                |                  <ProcessExtendedEffectivityFilter>Filter
                |                  Value</ProcessExtendedEffectivityFilter>
                |                  <ProcessExtendedEffectivityFilterCalcModelID>ID of Calculation
                |                  ModelFilter</ProcessExtendedEffectivityFilterCalcModelID>
                |                  <ProductExtendedEffectivityFilter>Filter
                |                  Value</ProductExtendedEffectivityFilter>
                |                  <ProductExtendedEffectivityFilterCalcModelID>ID of Calculation
                |                  ModelFilter</ProductExtendedEffectivityFilterCalcModelID>
                |                  <ResourceExtendedEffectivityFilter>Filter
                |                  Value</ResourceExtendedEffectivityFilter> 
                |                  <ResourceExtendedEffectivityFilterCalcModelID>ID of
                |                  Calculation ModelFilter</ResourceExtendedEffectivityFilterCalcModelID>
                |
                |               Attribute filters can be supplied using the following
                |               tags
                |               <AttributeFilters>
                |                  <ProcessAttributeFilters>
                |                    <AttributeFilter>
                |                       <PlanTypeName>Name of the
                |                       Plantype</PlanTypeName>
                |                       <AttributeName>Name of the
                |                       Attribute</AttributeName>
                |                       <Operator>Type of Operator. See list of legal values
                |                       below</Operator>
                |                       <AttributeValue>Value of the
                |                       Attribute</AttributeValue>
                |                       Add more <AttributeValue>...</AttributeValue> if more
                |                       attribute values need to be specified
                |                    </AttributeFilter>
                |                    Add more <AttributeFilter>...</AttributeFilter> if more
                |                    attribute filters need to be specified
                |                  </ProcessAttributeFilters>   
                |                  <ProductAttributeFilters>
                |                    Add <AttributeFilter>...</AttributeFilter> as specified
                |                    above
                |                  </ProductAttributeFilters>
                |                  <ResourceAttributeFilters>
                |                    Add <AttributeFilter>...</AttributeFilter> as specified
                |                    above
                |                  </ResourceAttributeFilters>
                |               </AttributeFilters>
                |
                |             Note: Instead of specifying plantype name, the object typename
                |             (e.g., "ergocompprocessdefault, "ergocomporgprocess", etc) can also be supplied
                |             if filter is to be applicable to all plantypes
                |             Note: For the <Operator> tag, the following are the legal
                |             values
                |                =
                |                !=
                |                <
                |                >
                |                <=
                |                >=
                |                LIKE
                |                NOT LIKE
                | 
                |     Example:
                | 
                |             In new way of filtering:
                |            iFilters = "<ProcessFilterSetName>Name</ProcessFilterSetName><ProductFilterSetName>Name</ProductFilterSetName><ResourceFilterSetName>Name</ResourceFilterSetName>"
                |            
                |         The order is NOT important. e.g.,
                |         "<ResourceFilterSetName>...</ResourceFilterSetName>" can come before
                |         "<ProcessFilterSetName>...</ProcessFilterSetName>"
                |          
                | 
                |     Example:
                | 
                |             In old way of filtering:
                |            iFilters = "<ProcessFilter>Process Type A</ProcessFilter><LabelFilter>Label B</LabelFilter><LineNumberFilter>10</LineNumberFilter>"
                |            
                |         The order is NOT important. e.g., "<LabelFilter>...</LabelFilter>" can
                |         come before "<ProcessFilter>...</ProcessFilter>"
                |
                |     Example:
                | 
                |             In old way of filtering:
                |            Example with attribute filers. Assuming user wishes to filter on
                |            Line Number 10 and load only those Workplans that are labelled "Workplan A" and
                |            "Workplan C"
                |            
                |         iFilters = "<LineNumberFilter>10</LineNumberFilter><AttributeFilters><ProcessAttributeFilters><AttributeFilter>
                |            <PlanTypeName>Workplan</PlanTypeName>
                |            <AttributeName>name</AttributeName>
                |            <Operator>=</Operator>
                |            <AttributeValue>Workplan A</AttributeValue>
                |            <AttributeValue>Workplan C</AttributeValue>
                |           </AttributeFilter></ProcessAttributeFilters></AttributeFilters>"
                |
                |     Returns:
                |         S_OK if all OK E_INVALIDARG if incorrect input format

        :param str i_filters:
        :rtype: None
        """
        return self.mhi_load_parameters.SetFilters(i_filters)

    def set_process_tree_id(self, i_process_tree_id: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetProcessTreeID(CATBSTR iProcessTreeID)
                | 
                |     Sets the "subcompitem" ID (oid) of process tree selected for the load For
                |     the topmost node in the tree, since no "subcompitem" ID is available, the
                |     "ergocompbase" ID has to be supplied
                | 
                |     Parameters:
                | 
                |         iProcessTreeID
                |             [in] ID of the process tree 
                | 
                |     Returns:
                |         S_OK in all cases

        :param str i_process_tree_id:
        :rtype: None
        """
        return self.mhi_load_parameters.SetProcessTreeID(i_process_tree_id)

    def set_product_bomid(self, i_product_bomid: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetProductBOMID(CATBSTR iProductBOMID)
                | 
                |     Sets the "subcompitem" ID (oid) of product BOM selected for the load For
                |     the topmost node in the tree, since no "subcompitem" ID is available, the
                |     "ergocompbase" ID has to be supplied
                | 
                |     Parameters:
                | 
                |         iProductBOMID
                |             [in] ID of the product BOM 
                | 
                |     Returns:
                |         S_OK in all cases

        :param str i_product_bomid:
        :rtype: None
        """
        return self.mhi_load_parameters.SetProductBOMID(i_product_bomid)

    def set_resource_tree_id(self, i_resource_tree_id: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetResourceTreeID(CATBSTR iResourceTreeID)
                | 
                |     Sets the "subcompitem" ID (oid) of resource tree selected for the load For
                |     the topmost node in the tree, since no "subcompitem" ID is available, the
                |     "ergocompbase" ID has to be supplied
                | 
                |     Parameters:
                | 
                |         iResourceTreeID
                |             [in] ID of the resource tree 
                | 
                |     Returns:
                |         S_OK in all cases

        :param str i_resource_tree_id:
        :rtype: None
        """
        return self.mhi_load_parameters.SetResourceTreeID(i_resource_tree_id)

    def set_selected_object_id(self, i_selected_object_id: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSelectedObjectID(CATBSTR iSelectedObjectID)
                | 
                |     Sets the "ergocompbase" ID (oid) of selected object (object use to start
                |     the load).
                | 
                |     Parameters:
                | 
                |         iSelectedObjectID
                |             [in] ID of the selected object 
                | 
                |     Returns:
                |         S_OK in all cases

        :param str i_selected_object_id:
        :rtype: None
        """
        return self.mhi_load_parameters.SetSelectedObjectID(i_selected_object_id)

    def __repr__(self):
        return f'MHILoadParameters(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_standard_contour_parameters import SFMStandardContourParameters
from pycatia.cat_str_functional_interfaces.sfm_standard_pos_strategy_parameters import SFMStandardPosStrategyParameters
from pycatia.system_interfaces.any_object import AnyObject


class SFMStandardOpening(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SfmStandardOpening
                | 
                | Defines Edition Techniques for Standard Openings.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_standard_opening = com_object

    def get_contour(self, o_contour_name: str, o_list_contour_params: SFMStandardContourParameters) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetContour(CATBSTR oContourName,
                | SfmStandardContourParameters oListContourParams)
                | 
                |     Gets Contour Information for Standard Opening.
                | 
                |     Parameters:
                | 
                |         oContourName
                |             [out] The name of the Standard Opening contour for this opening.
                |             
                |         oListContourParams
                |             [out] A list of volatile objects (accessed through CATIAParameter)
                |             specifying Cke parameters controlling the size of this contour. The Cke
                |             parameters are retrieved using the CATIAParameter interface. These Cke
                |             parameters are normally persistent parameter objects in the model (if they have
                |             been stored), but in some cases, these may be volatile parameters. The
                |             parameters are locked if they cannot be modified. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This Example retrieves the contour information for standard
                |             opening.
                | 
                |              Dim StrContourName As String
                |              Dim StrContourParams As
                |              SfmStandardContourParameters
                |              StdOpening.GetContour StrContourName,
                |              StrContourParams

        :param str o_contour_name:
        :param SFMStandardContourParameters o_list_contour_params:
        :rtype: None
        """
        return self.sfm_standard_opening.GetContour(o_contour_name, o_list_contour_params.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_contour'
        # # vba_code = """
        # # Public Function get_contour(sfm_standard_opening)
        # #     Dim oContourName (2)
        # #     sfm_standard_opening.GetContour oContourName
        # #     get_contour = oContourName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_positioning_strategy(
            self,
            o_pos_strategy_name: str,
            o_list_pos_params: SFMStandardPosStrategyParameters
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetPositioningStrategy(CATBSTR oPosStrategyName,
                | SfmStandardPosStrategyParameters oListPosParams)
                | 
                |     Gets the list of Position Strategy Parameters.
                | 
                |     Parameters:
                | 
                |         oPosStrategyName
                |             [out] The name of the Standard Opening Position Strategy for this
                |             opening. 
                |         oListPosParams
                |             [out] A list of the parameter group objects defining the
                |             Positioning Specification. The number and types of objects in this list depend
                |             on the Positioning Strategy name. 
                | 
                |     See also:
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This Example retrieves the Position Strategy information for
                |             existing standard opening.
                | 
                |              Dim StrPosStrategyName As String
                |              Dim StrPosStrategyParams As
                |              SfmStandardPosStrategyParameters
                |              StdOpening1.GetPositioningStrategy StrPosStrategyName,
                |              StrPosStrategyParams

        :param str o_pos_strategy_name:
        :param SFMStandardPosStrategyParameters o_list_pos_params:
        :rtype: None
        """
        return self.sfm_standard_opening.GetPositioningStrategy(o_pos_strategy_name, o_list_pos_params.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_positioning_strategy'
        # # vba_code = """
        # # Public Function get_positioning_strategy(sfm_standard_opening)
        # #     Dim oPosStrategyName (2)
        # #     sfm_standard_opening.GetPositioningStrategy oPosStrategyName
        # #     get_positioning_strategy = oPosStrategyName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_contour(self, i_contour_name: str, i_list_contour_params: SFMStandardContourParameters) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetContour(CATBSTR iContourName,
                | SfmStandardContourParameters iListContourParams)
                | 
                |     Sets Contour Information for Standard Opening.
                | 
                |     Parameters:
                | 
                |         iContourName
                |             [in] The name of the Standard Opening contour for this opening.
                |             
                |         iListContourParams
                |             [in] A list of volatile objects (accessed through CATIAParameter)
                |             specifying Cke parameters controlling the size of this contour. The Cke
                |             parameters are retrieved using the CATIAParameter interface. These Cke
                |             parameters are normally persistent parameter objects in the model (if they have
                |             been stored), but in some cases, these may be volatile parameters. The
                |             parameters are locked if they cannot be modified. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This Example changes the parameter values for existing opening
                |             created using "Sfm_rect" contour.
                | 
                |              ' First Get the Conotur.
                |              Dim StrContourName As String
                |              Dim StrContourParams As
                |              SfmStandardContourParameters
                |              StdOpening.GetContour StrContourName StrContourParams
                |              
                |              ' Get The count
                |              Dim NbofParams As Long
                |              NbofParams = StrContourParams .Count
                |              ' Modify the values inside the for loop
                |              Dim ParamName As String
                |              Dim ParamValue As Parameter
                |              For i = 1 To NbofParams 
                |               Set ParamValue = StrContourParams .Item(i)
                |               ParamName = ParamValue.Name
                |               If ParamName = "Sfm_Width" Then
                |                 ParamValue .ValuateFromString ("1000mm")
                |                 End If
                |               If ParamName = "Sfm_Height" Then
                |                 ParamValue .ValuateFromString ("1000mm")
                |                  End If
                |               If ParamName = "Sfm_CornerRadius" Then
                |                 ParamValue .ValuateFromString ("25mm")
                |                  End If
                |              Next
                |              ' Set the contour with new values
                |              StdOpening.SetContour StrContourName , StrContourParams

        :param str i_contour_name:
        :param SFMStandardContourParameters i_list_contour_params:
        :rtype: None
        """
        return self.sfm_standard_opening.SetContour(i_contour_name, i_list_contour_params.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_contour'
        # # vba_code = """
        # # Public Function set_contour(sfm_standard_opening)
        # #     Dim iContourName (2)
        # #     sfm_standard_opening.SetContour iContourName
        # #     set_contour = iContourName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_positioning_strategy(
            self,
            i_pos_strategy_name: str,
            i_list_pos_params: SFMStandardPosStrategyParameters
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPositioningStrategy(CATBSTR iPosStrategyName,
                | SfmStandardPosStrategyParameters iListPosParams)
                | 
                |     Sets the Position Strategy and Positin Strategy
                |     Parameters.
                | 
                |     Parameters:
                | 
                |         iPosStrategyName
                |             [in] The name of the Standard Opening Position Strategy for this
                |             opening. 
                |         iListPosParams
                |             [in] A list of the parameter group objects defining the Positioning
                |             Specification. The number and types of objects in this list depend on the
                |             Positioning Strategy name. 
                | 
                |     See also:
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This Example modifies the Position Strategy Parameters for existing
                |             standard opening created using
                |             CATSfmPosOffsetOffset.
                | 
                |              'Prepare a New List for U References. The list will now contain
                |              one element.
                |              Dim UrefListNew As SfmReferences
                |              Dim UrefNew As Reference
                |              Set UrefNew = Part1.FindObjectByName("CROSS.95")
                |              UrefListNew.Add UrefNew
                |              'Prepare a New List for VReferences. The list will now contain one
                |              element.
                |              Dim VrefListNew As SfmReferences
                |              Dim VrefNew As Reference
                |              Set VrefNew = Part1.FindObjectByName("LONG.0")
                |              VrefListNew.Add VrefNew
                |              'Get Position Strategy Name and Parameters
                |              Dim StrPosStrategyName As String
                |              Dim StrPosStrategyParams As
                |              SfmStandardPosStrategyParameters
                |              StdOpening1.GetPositioningStrategy StrPosStrategyName,
                |              StrPosStrategyParams
                |              'SetPosParamData on retrieved StrPosStrategyParams. Enter new
                |              values for offset, rotation angle & reference
                |              list
                |              StrPosStrategyParams.SetPosParamData "CATSfmPosOffsetOffset", 40,
                |              UrefListNew, 25, UrefListNew, 30
                |              StdOpening1.SetPositioningStrategy StrPosStrategyName,
                |              StrPosStrategyParams
                |              Part1.Update

        :param str i_pos_strategy_name:
        :param SFMStandardPosStrategyParameters i_list_pos_params:
        :rtype: None
        """
        return self.sfm_standard_opening.SetPositioningStrategy(i_pos_strategy_name, i_list_pos_params.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_positioning_strategy'
        # # vba_code = """
        # # Public Function set_positioning_strategy(sfm_standard_opening)
        # #     Dim iPosStrategyName (2)
        # #     sfm_standard_opening.SetPositioningStrategy iPosStrategyName
        # #     set_positioning_strategy = iPosStrategyName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SFMStandardOpening(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity


class MoveJointsAct(Activity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         MoveJointsAct
                | 
                | Interface representing a MoveJointsAct.
                | 
                | Role: This interface is used to retrieve/assign the value of motion
                | targets/attrs for the MoveJointsAct.
                | The following code snippet can be used to obtain a MoveJointsAct from a
                | selected Activity
                | 
                |    Dim oSelectAct As Activity
                |    Set oSelectAct = CATIA.ActiveDocument.Selection.FindObject("CATIAActivity")
                |    Dim objMoveAct As MoveJointsAct
                |    Set objMoveAct = oSelectAct.GetTechnologicalObject("MoveJointsAct")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.move_joints_act = com_object

    @property
    def acceleration(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Acceleration() As double
                | 
                |     This property returns and sets the Acceleration percentage for the
                |     activity. • For straight line motion, the percentage of the maximum TCP linear
                |     acceleration • For joint-interpolated motion, the percentage of the maximum
                |     joint acceleration
                | 
                |     Returns:
                |         oAccel The Speed Percent for the activity. 
                |     Parameters:
                | 
                |         iAccel
                |             The specified Speed Percent for the activity. 
                | 
                |     Example:
                |
                |            Dim objMoveAct As MoveJointsAct
                |                   ......
                |            Dim  Accl as Double
                |            Accl=objMoveAct.Acceleration
                |            Accl  = 30
                |            objMoveAct.Acceleration=Accl

        :rtype: float
        """

        return self.move_joints_act.Acceleration

    @acceleration.setter
    def acceleration(self, value: float):
        """
        :param float value:
        """

        self.move_joints_act.Acceleration = value

    @property
    def corner_rounding(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CornerRounding() As double
                | 
                |     This property returns and sets the Corner Rounding for the activity. Corner
                |     Rounding::The percentage represents the extent to which the device decelerates
                |     as it rounds the corner.
                | 
                |     Returns:
                |         oCornerRounding The Corner Rounding for the activity. 
                |     Parameters:
                | 
                |         iCornerRounding
                |             The specified Corner Rounding for the activity. 
                | 
                |     Example:
                |
                |            Dim objMoveAct As MoveJointsAct
                |                   ......
                |            Dim  Rounding as Double
                |            Rounding=objMoveAct.CornerRounding
                |            Rounding = 30
                |            objMoveAct.CornerRounding=Rounding

        :rtype: float
        """

        return self.move_joints_act.CornerRounding

    @corner_rounding.setter
    def corner_rounding(self, value: float):
        """
        :param float value:
        """

        self.move_joints_act.CornerRounding = value

    @property
    def joint_values(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property JointValues() As CATSafeArrayVariant
                | 
                |     This property returns and sets the joint values for the
                |     activity.
                | 
                |     Returns:
                |         oJointVal The joint values for the activity. 
                |     Parameters:
                | 
                |         iJointVal
                |             The specified joint values for the activity. 
                | 
                |     Example:
                |
                |            Dim objMoveAct As MoveJointsAct
                |                   ......
                |            Dim  ListOfJointValues() 
                |            ListOfJointValues=objMoveAct.JointValues
                |            ..
                |            For i = 0 to ubound (ListOfJointValues)
                |               ...
                |            Next
                |            objMoveAct.JointValues=ListOfJointValues

        :rtype: tuple
        """

        return self.move_joints_act.JointValues

    @joint_values.setter
    def joint_values(self, value: tuple):
        """
        :param tuple value:
        """

        self.move_joints_act.JointValues = value

    @property
    def mechanism_index(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MechanismIndex() As short
                | 
                |     Sets and Retrieves mechanism index for the activity. The index of mechanism
                |     in the list of mechanisms of the owning resource.
                | 
                |     Returns:
                |         oMechanismIndex The mechanism index for the activity. 
                |     Parameters:
                | 
                |         iMechanismIndex
                |             The specified mechanism index for the activity. 
                | 
                |     Example:
                |
                |            Dim objMoveAct As MoveJointsAct
                |                   ......
                |            Dim  MechIndex as Integer
                |            MechIndex=objMoveAct.MechanismIndex
                |            MechIndex = 1
                |            objMoveAct.MechanismIndex=MechIndex

        :rtype: int
        """

        return self.move_joints_act.MechanismIndex

    @mechanism_index.setter
    def mechanism_index(self, value: int):
        """
        :param int value:
        """

        self.move_joints_act.MechanismIndex = value

    @property
    def motion_basis(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MotionBasis() As CATBSTR
                | 
                |     Sets and Retrieves Motion Basis defined for the activity ("TIME" /
                |     "SPEED")
                | 
                |     Returns:
                |         oMotionBasis The Motion Basis for the activity. 
                |     Parameters:
                | 
                |         iMotionBasis
                |             The specified Motion Basis for the activity. 
                | 
                |     Example:
                |
                |            Dim objMoveAct As MoveJointsAct
                |                   ......
                |            Dim  MotionBas as string
                |            MotionBas=objMoveAct.MotionBasis
                |            MotionBas  = "SPEED"
                |            objMoveAct.MotionBasis=MotionBas

        :rtype: str
        """

        return self.move_joints_act.MotionBasis

    @motion_basis.setter
    def motion_basis(self, value: str):
        """
        :param str value:
        """

        self.move_joints_act.MotionBasis = value

    @property
    def speed_percent(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SpeedPercent() As double
                | 
                |     This property returns and sets the speed value percentage for the activity.
                |     • For straight line motion, the percentage of the maximum TCP linear speed. •
                |     For joint-interpolated motion, the percentage of the maximum joint
                |     speed.
                | 
                |     Returns:
                |         oSpeedPercent The Speed Percent for the activity. 
                |     Parameters:
                | 
                |         iSpeedPercent
                |             The specified Speed Percent for the activity. 
                | 
                |     Example:
                |
                |            Dim objMoveAct As MoveJointsAct
                |                   ......
                |            Dim  SpeedValPr as Double
                |            SpeedValPr=objMoveAct.SpeedPercent
                |            SpeedValPr = 80
                |            objMoveAct.SpeedPercent=SpeedValPr

        :rtype: float
        """

        return self.move_joints_act.SpeedPercent

    @speed_percent.setter
    def speed_percent(self, value: float):
        """
        :param float value:
        """

        self.move_joints_act.SpeedPercent = value

    def __repr__(self):
        return f'MoveJointsAct(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.structure_interfaces.str_anchor_point import StrAnchorPoint
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class StrAnchorPoints(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     StrAnchorPoints
                | 
                | A collection of the anchor points of a section object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=StrAnchorPoint)
        self.str_anchor_points = com_object

    def item(self, i_index: cat_variant) -> StrAnchorPoint:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As StrAnchorPoint
                | 
                |     Returns an anchor point from its index in the anchor points
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the anchor point to retrieve in the collection of
                |             anchor points. This index can either be the rank of the anchor point in the
                |             collection or the name you assign to the anchor point. As a numerics, this
                |             index is the rank of the anchor point in the collection. The index of the first
                |             anchor point in the collection is 1, and the index of the last anchor point is
                |             Count. As a string, it is the name you assigned to the member using the
                |             
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved anchor point

        :param cat_variant i_index:
        :rtype: StrAnchorPoint
        """
        return StrAnchorPoint(self.str_anchor_points.Item(i_index))

    def __repr__(self):
        return f'StrAnchorPoints(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.mec_mod_interfaces.vertex import Vertex


class NotWireBoundaryMonoDimFeatVertex(Vertex):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Reference
                |                         MecModInterfaces.Boundary
                |                             MecModInterfaces.Vertex
                |                                NotWireBoundaryMonoDimFeatVertex
                | 
                | 0-D boundary belonging to a feature whose topological result is one
                | dimensional, the boundary not beeing the extremity of the
                | feature.
                | Role: This Boundary object may be, for example, in a part containing a Sketch
                | which is made up of a circle arc and a spline, the vertex between the circle
                | arc and the spline.
                | You will create a NotWireBoundaryMonoDimFeatVertex object using the
                | Shapes.GetBoundary , HybridShapes.GetBoundary , Sketches.GetBoundary or
                | Selection.SelectElement2 method. Then, you pass it to the
                | operator.
                | The lifetime of a NotWireBoundaryMonoDimFeatVertex object is limited, see
                | Boundary.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.not_wire_boundary_mono_dim_feat_vertex = com_object

    def __repr__(self):
        return f'NotWireBoundaryMonoDimFeatVertex(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class PCBObject(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PCBObject

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.pcb_object = com_object

    @property
    def electronic_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ElectronicType() As CatElectronicType (Read Only)
                | 
                |     Allow to know if : a Product is a BOARD, a PANEL or a COMPONENT, a Hole is a PBD Hole
                |     a pattenr is a PCB pattern, a Pad is a constraint area.
                | 
                |     Parameters:
                | 
                |         oType
                |             This parameter is the type of the object ( BOARD, PANEL, COMPONENT )
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :return: enum cat_electronic_type
        :rtype: int
        """

        return self.pcb_object.ElectronicType

    def remove_electronic_behaviour(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveElectronicBehaviour()
                | 
                |     Allow to remove a PCB behaviour of an object
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: None
        """
        return self.pcb_object.RemoveElectronicBehaviour()

    def __repr__(self):
        return f'PCBObject(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.knowledge_interfaces.parameters import Parameters
from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.funct_system_interfaces.functional_document import FunctionalDocument


class FunctionalElement(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     FunctionalElement
                | 
                | Represents a Functional Element.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.functional_element = com_object

    @property
    def document(self) -> 'FunctionalDocument':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Document() As FunctionalDocument (Read Only)
                | 
                |     Returns the Document.

        :rtype: FunctionalDocument
        """

        return FunctionalDocument(self.functional_element.Document)

    @property
    def parameters(self) -> Parameters:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Parameters() As Parameters (Read Only)
                | 
                |     Returns the parameters collection.

        :rtype: Parameters
        """

        return Parameters(self.functional_element.Parameters)

    def __repr__(self):
        return f'FunctionalElement(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_connection_parameters import SFMConnectionParameters
from pycatia.cat_str_functional_interfaces.sfm_endcut import SFMEndcut
from pycatia.cat_str_functional_interfaces.sfm_object import SFMObject
from pycatia.cat_str_functional_interfaces.sfm_references import SFMReferences
from pycatia.cat_str_functional_interfaces.sfm_slots import SFMSlots
from pycatia.in_interfaces.reference import Reference
from pycatia.in_interfaces.references import References


class SFMProfile(SFMObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATStrFunctionalInterfaces.SfmObject
                |                         SfmProfile
                | 
                | Interface to manage the structure frame modeling member object Role: Allows
                | accessing and setting of member's data.
                | 
                | See also:
                |     SfmFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_profile = com_object

    @property
    def anchor_point(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnchorPoint() As CATBSTR
                | 
                |     Returns or sets the member's anchor point.
                | 
                |     Example:
                |         This example retrieves in AnchorPointName the anchor point name of the
                |         SfmProfile feature.
                | 
                |          Dim AnchorPointName As String
                |          Set AnchorPointName = SfmProfile.AnchorPoint

        :rtype: str
        """

        return self.sfm_profile.AnchorPoint

    @anchor_point.setter
    def anchor_point(self, value: str):
        """
        :param str value:
        """

        self.sfm_profile.AnchorPoint = value

    @property
    def section_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SectionName() As CATBSTR
                | 
                |     Returns or sets the member's section name.
                | 
                |     Example:
                |         This example retrieves in Name the name of section user by the
                |         SfmProfile feature.
                | 
                |          Dim Name As String
                |          Set Name = SfmProfile.SectionName

        :rtype: str
        """

        return self.sfm_profile.SectionName

    @section_name.setter
    def section_name(self, value: str):
        """
        :param str value:
        """

        self.sfm_profile.SectionName = value

    @property
    def split_profiles(self) -> References:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SplitProfiles() As References (Read Only)
                | 
                |     Returns the SplitProfiles.
                | 
                |     Example:
                |         This example retrieves SplitProfiles list of the
                |         Stiffener.
                | 
                |          Dim SplitStiffeners As References
                |          Set SplitStiffeners = SuperStiffener.SplitProfiles
                |          Dim SplitStiffener1 As Reference
                |          Set SplitStiffener1 = SplitStiffeners.Item(1)
                |          Set SelctionObj = CATIA.ActiveDocument.Selection
                |          SelctionObj.Add SplitStiffener1
                |          Dim SplitStiff1 As SfmStiffener
                |          Set SplitStiff1 = SelctionObj.FindObject("CATIASfmStiffener")

        :rtype: References
        """

        return References(self.sfm_profile.SplitProfiles)

    @property
    def support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Support() As Reference (Read Only)
                | 
                |     Returns the member's support.
                | 
                |     Example:
                |         This example retrieves in Support the support of the SfmProfile
                |         feature.
                | 
                |          Dim Support As Reference
                |          Set Support = SfmProfile.Support

        :rtype: Reference
        """

        return Reference(self.sfm_profile.Support)

    def add_endcut(
            self,
            i_extremity_index: int,
            i_endcut_type: str,
            i_endcut_name: str,
            i_list_context: SFMReferences,
            i_list_parameters: SFMConnectionParameters
    ) -> SFMEndcut:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddEndcut(long iExtremityIndex,
                | CATBSTR iEndcutType,
                | CATBSTR iEndcutName,
                | SfmReferences iListContext,
                | SfmConnectionParameters iListParameters) As SfmEndcut
                | 
                |     Creates Endcut on a SuperProfile.Use the method to create as well as edit
                |     the endcut.
                | 
                |     Parameters:
                | 
                |         iExtremityIndex
                |             [in] The extremity on which endcut is to be applied(1-Start,2-End).
                |             
                |         iEndcutType
                |             [in] The type of Endcut(Snipe,Trim,Weld). 
                |         iEndcutName
                |             [in] Name of the Endcut. 
                |         iListContext
                |             [in] Context inputs for contextual endcuts or cutbacks.Not required
                |             for Custom. 
                |         iListParameters
                |             [in] The list of Parameters. 
                |         oSfmProfileEndCut
                |             [out] The created Endcut. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This Example creates a new contextual endcut on Stiifener Start
                |             extremity.
                | 
                |              ' First read the specifications required for
                |              endcut
                |              Dim FactoryObj As SfmOperationFactory
                |              Set FactoryObj = PartObj.GetCustomerFactory("SfmOperationFactory")
                |              Dim EndCutManagerObj As SfmEndcutManager
                |              Set EndCutManagerObj = FactoryObj.GetEndcutManager
                |              Dim ListOfContextNames, ListOfUDFParamNames As
                |              Variant
                |              Dim ListOfUDFParameters As
                |              SfmConnectionParameters
                |              EndCutManagerObj.GetEndcutSpecifications "Tee", "Snipe",
                |              "T-CTX-PLATE", ListOfContextNames, ListOfUDFParameters,
                |              ListOfUDFParamNames
                |              ' Read the Name of Context
                |              Dim SizeOfContextNames As Long
                |              SizeOfContext = UBound(ListOfContextNames)
                |              Dim ContextName As String
                |              For i = 0 To SizeOfContext  
                |               ContextName = ListOfContextNames(i)
                |              Next
                |              ' Read and Set the Parameter Values
                |              Dim SizeOfUDFParams As Long
                |              SizeOfUDFParams = ListOfUDFParameters.Count
                |              Dim UDFParam As Parameter
                |              For i = 1 To SizeOfUDFParams  
                |               Set UDFParam = ListOfUDFParameters.Item(i)
                |               Dim UDFParamName,UDFParamValue As String
                |               UDFParamName = ListOfUDFParamNames(j - 1)
                |               UDFParamValue = UDFParam.ValueAsString
                |              'Redefine Param Value
                |               If (UDFParamName = "Snipe Radius") Then
                |                 UDFParam.ValuateFromString ("52mm")
                |               End If
                |              Next
                |              ' Define the Context
                |              Dim FactoryRef As SfmFunctionFactory
                |              Set FactoryRef = PartObj.GetCustomerFactory("SfmFunctionFactory")
                |              Dim ListOfContexts As SfmReferences
                |              Set ListOfContexts = FactoryRef.SfmReferences
                |              Dim Limit As Reference
                |              Set Limit = PartObj.CreateReferenceFromObject(SfmSuperPlateObj)
                |              ListOfContexts.Add Limit
                |              ' Create the Endcut
                |              Dim EndCutObj As SfmEndcut
                |              Set EndCutObj = SfmStiffenerObj.AddEndcut(1, "Snipe", "T-CTX-PLATE", ListOfContexts, ListOfUDFParameters)
                |              ' For Non Conetxtual Endcuts pass Nothing for
                |              iListContext
                |              Set EndCutObj = SfmStiffenerObj.AddEndcut(1, "Snipe", "Web_Snipe_Radius", Nothing, ListOfUDFParameters)

        :param int i_extremity_index:
        :param str i_endcut_type:
        :param str i_endcut_name:
        :param SFMReferences i_list_context:
        :param SFMConnectionParameters i_list_parameters:
        :rtype: SFMEndcut
        """
        return SFMEndcut(
            self.sfm_profile.AddEndcut(
                i_extremity_index,
                i_endcut_type,
                i_endcut_name,
                i_list_context.com_object,
                i_list_parameters.com_object
            )
        )

    def get_end_coord(self, o_coord: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetEndCoord(CATSafeArrayVariant oCoord)
                | 
                |     Retrieves the coordinates of the member's end extremity.
                | 
                |     Example
                |     :
                |         This example retrieves in EndExtr the end extremity coordinates of the
                |         SfmProfile feature.
                | 
                |          SfmProfile.GetEndCoord EndExtr

        :param tuple o_coord:
        :rtype: None
        """
        return self.sfm_profile.GetEndCoord(o_coord)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_end_coord'
        # # vba_code = """
        # # Public Function get_end_coord(sfm_profile)
        # #     Dim oCoord (2)
        # #     sfm_profile.GetEndCoord oCoord
        # #     get_end_coord = oCoord
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_endcut(self, i_extremity_index: int) -> SFMEndcut:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetEndcut(long iExtremityIndex) As SfmEndcut
                | 
                |     Retrieves Existing Endcut on Profile.
                | 
                |     Parameters:
                | 
                |         iExtremityIndex
                |             [in] Extremity of Profile(1-Start,2-End). 
                |         oSfmEndcut
                |             [out] Retrieved Endcut. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This example gets the Existing Endcut.
                | 
                |              Dim EndCutObj As SfmEndcut
                |              Set EndCutObj = ProfileObj.GetEndcut(1)

        :param int i_extremity_index:
        :rtype: SFMEndcut
        """
        return SFMEndcut(self.sfm_profile.GetEndcut(i_extremity_index))

    def get_profile_limit(self, i_extremity_index: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetProfileLimit(long iExtremityIndex) As Reference
                | 
                |     Returns the limit at an Extremity of a Profile.
                | 
                |     Parameters:
                | 
                |         iExtremityIndex
                |             [in] Extremity of Profile(1-Start,2-End). 
                |         oLimit
                |             [out] Existing Limit. 
                | 
                |     Returns:
                |         S_OK if everything ran ok.
                | 
                |         Example:
                |             This example retrieves the Start Limit of a
                |             Stiffener.
                | 
                |              Dim ProfileLimit As Reference
                |              Set ProfileLimit = SuperStiffenerObj.GetProfileLimit(1)

        :param int i_extremity_index:
        :rtype: Reference
        """
        return Reference(self.sfm_profile.GetProfileLimit(i_extremity_index))

    def get_section_axis(
            self,
            i_abside: float,
            i_origin: tuple,
            io_vector1: tuple,
            io_vector2: tuple,
            io_vector3: tuple
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetSectionAxis(double iAbside,
                | CATSafeArrayVariant iOrigin,
                | CATSafeArrayVariant ioVector1,
                | CATSafeArrayVariant ioVector2,
                | CATSafeArrayVariant ioVector3)
                | 
                |     Retrieves the axis system of the section at a given location on the
                |     member's support.
                | 
                |     Example:
                |         This example retrieves in Origin, Vector1, Vector2, Vector3 the section
                |         axis at the start extremity of the SfmProfile feature.
                | 
                |          Dim Origin, Vector1, Vector2, Vector3 As 
                |          SfmProfile.GetSectionAxis 0., Origin, Vector1, Vector2,
                |          Vector3

        :param float i_abside:
        :param tuple i_origin:
        :param tuple io_vector1:
        :param tuple io_vector2:
        :param tuple io_vector3:
        :rtype: None
        """
        return self.sfm_profile.GetSectionAxis(
            i_abside,
            i_origin,
            io_vector1,
            io_vector2,
            io_vector3
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_section_axis'
        # # vba_code = """
        # # Public Function get_section_axis(sfm_profile)
        # #     Dim iAbside (2)
        # #     sfm_profile.GetSectionAxis iAbside
        # #     get_section_axis = iAbside
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_slots_on_profile(self) -> SFMSlots:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSlotsOnProfile() As SfmSlots
                | 
                |     Retrieves Slots on Profile.
                | 
                |     Parameters:
                | 
                |         oSfmSlots
                |             [out] Slots. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This example gets the Slots.
                | 
                |              Dim SlotsonProfile As SfmSlots
                |              Set SlotsonProfile = ProfileObj.GetSlotsOnProfile

        :rtype: SFMSlots
        """
        return SFMSlots(self.sfm_profile.GetSlotsOnProfile())

    def get_start_coord(self, o_coord: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetStartCoord(CATSafeArrayVariant oCoord)
                | 
                |     Retrieves the coordinates of the member's start extremity.
                | 
                |     Example
                |     :
                |         This example retrieves in StartExtr the start extremity coordinates of
                |         the SfmProfile feature.
                | 
                |          SfmProfile.GetStartCoord StartExtr

        :param tuple o_coord:
        :rtype: None
        """
        return self.sfm_profile.GetStartCoord(o_coord)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_start_coord'
        # # vba_code = """
        # # Public Function get_start_coord(sfm_profile)
        # #     Dim oCoord (2)
        # #     sfm_profile.GetStartCoord oCoord
        # #     get_start_coord = oCoord
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_endcut(self, i_extremity_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveEndcut(long iExtremityIndex)
                | 
                |     Removes Existing Endcut on Profile.
                | 
                |     Parameters:
                | 
                |         iExtremityIndex
                |             [in] Extremity of Profile(1-Start,2-End). 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This example removes the Existing Endcut.
                | 
                |              Dim EndCutObj As SfmEndcut
                |              Set EndCutObj = ProfileObj.RemoveEndcut(1)

        :param int i_extremity_index:
        :rtype: None
        """
        return self.sfm_profile.RemoveEndcut(i_extremity_index)

    def run(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Run()
                | 
                |     Compute the member's result.
                | 
                |     Example:
                |         This example builds the result of the SfmProfile
                |         feature.
                | 
                |          SfmProfile.Run

        :rtype: None
        """
        return self.sfm_profile.Run()

    def set_profile_limit(self, i_extremity_index: int, i_limit: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetProfileLimit(long iExtremityIndex,
                | Reference iLimit)
                | 
                |     Sets the limit at an Extremity of a Profile.
                | 
                |     Parameters:
                | 
                |         iExtremityIndex
                |             [in] Extremity of Profile(1-Start,2-End). 
                |         iLimit
                |             [in] New Limit to add. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This example sets the limit at the Extremity.
                | 
                |              Set StiffenerLimit = ObjPart.FindObjectByName("CROSS.115")
                |              Dim LimitRef As Reference
                |              Set LimitRef = ObjPart.CreateReferenceFromObject(StiffenerLimit)
                |              SuperStiffener.SetProfileLimit 2, LimitRef

        :param int i_extremity_index:
        :param Reference i_limit:
        :rtype: None
        """
        return self.sfm_profile.SetProfileLimit(i_extremity_index, i_limit.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_profile_limit'
        # # vba_code = """
        # # Public Function set_profile_limit(sfm_profile)
        # #     Dim iExtremityIndex (2)
        # #     sfm_profile.SetProfileLimit iExtremityIndex
        # #     set_profile_limit = iExtremityIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SFMProfile(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_rsc_interfaces.rendering_environment_wall import RenderingEnvironmentWall
from pycatia.system_interfaces.any_object import AnyObject


class RenderingEnvironment(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     RenderingEnvironment
                | 
                | Represents a Environment object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.rendering_environment = com_object

    @property
    def active_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ActiveStatus() As short
                | 
                |     Returns or sets the environment active status.
                |     Only one environment can be active for a product. The active status can
                |     be:
                |     1: environment is activated
                |     0: environment is deactivated

        :rtype: int
        """

        return self.rendering_environment.ActiveStatus

    @active_status.setter
    def active_status(self, value: int):
        """
        :param int value:
        """

        self.rendering_environment.ActiveStatus = value

    @property
    def face_number(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FaceNumber() As short
                | 
                |     Returns or sets the spherical environment face number.
                |     The default value for a new spherical environment is 2.
                |     If face number is set to 1, a mapped texture image will covered whole
                |     environment sphere.
                |     If face number is set to 2, two different texture images can be mapped for
                |     upper hemisphere and lower hemisphere.
                |     N.B. This property is useless for cubical and cylindrical environments.

        :rtype: int
        """

        return self.rendering_environment.FaceNumber

    @face_number.setter
    def face_number(self, value: int):
        """
        :param int value:
        """

        self.rendering_environment.FaceNumber = value

    @property
    def height(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Height() As double
                | 
                |     Returns or sets the cubic or cylindrical environment height value.

        :rtype: float
        """

        return self.rendering_environment.Height

    @height.setter
    def height(self, value: float):
        """
        :param float value:
        """

        self.rendering_environment.Height = value

    @property
    def length(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Length() As double
                | 
                |     Returns or sets the cubic environment length value.

        :rtype: float
        """

        return self.rendering_environment.Length

    @length.setter
    def length(self, value: float):
        """
        :param float value:
        """

        self.rendering_environment.Length = value

    @property
    def radius(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Radius() As double
                | 
                |     Returns or sets the spherical or cylindrical environment radius value.

        :rtype: float
        """

        return self.rendering_environment.Radius

    @radius.setter
    def radius(self, value: float):
        """
        :param float value:
        """

        self.rendering_environment.Radius = value

    @property
    def width(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Width() As double
                | 
                |     Returns or sets the cubic environment width value.

        :rtype: float
        """

        return self.rendering_environment.Width

    @width.setter
    def width(self, value: float):
        """
        :param float value:
        """

        self.rendering_environment.Width = value

    def get_origin(self, o_origin: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetOrigin(CATSafeArrayVariant oOrigin)
                | 
                |     Returns the coordinates of the origin of the environment.
                |     These coordinates are set as an array of 3 Variants (double type).

        :param tuple o_origin:
        :rtype: None
        """
        return self.rendering_environment.GetOrigin(o_origin)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_origin'
        # # vba_code = """
        # # Public Function get_origin(rendering_environment)
        # #     Dim oOrigin (2)
        # #     rendering_environment.GetOrigin oOrigin
        # #     get_origin = oOrigin
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetType() As short
                | 
                |     Returns the environment type.
                | 
                |         Possible environment types are:
                |         1: Cubical environment
                |         2: Spherical environment
                |         3: Cylindrical environment

        :rtype: int
        """
        return self.rendering_environment.GetType()

    def get_vertical_axis(self, o_axis: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetVerticalAxis(CATSafeArrayVariant oAxis)
                | 
                |     Returns the coordinates of the vertical axis vector of the
                |     environment.
                |     These coordinates are set as an array of 3 Variants (double type).

        :param tuple o_axis:
        :rtype: None
        """
        return self.rendering_environment.GetVerticalAxis(o_axis)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_vertical_axis'
        # # vba_code = """
        # # Public Function get_vertical_axis(rendering_environment)
        # #     Dim oAxis (2)
        # #     rendering_environment.GetVerticalAxis oAxis
        # #     get_vertical_axis = oAxis
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_wall(self, i_type: int) -> RenderingEnvironmentWall:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetWall(short iType) As RenderingEnvironmentWall
                | 
                |     Returns the environment walls.
                |     The environment wall type can be:
                |     1: North wall (for cubical and cylindrical environments)
                |     2: South wall (for cubical and cylindrical environments)
                |     3: East wall (for cubical environments)
                |     4: West wall (for cubical environments)
                |     5: Top wall (for cubical, cylindrical and shperical
                |     environments)
                |     6: Bottom wall (for cubical, cylindrical and shperical
                |     environments)

        :param int i_type:
        :rtype: RenderingEnvironmentWall
        """
        return RenderingEnvironmentWall(self.rendering_environment.GetWall(i_type))

    def put_origin(self, i_origin: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PutOrigin(CATSafeArrayVariant iOrigin)
                | 
                |     Sets the coordinates of the origin of the environment.
                |     These coordinates are set as an array of 3 Variants (double
                |     type).
                | 
                |     Example:
                |         This example sets the origin of the MyEnvironment environment. to the
                |         point with coordinates (10, 25, 15).
                | 
                |          MyEnvironment.PutOrigin Array(10, 25, 15)

        :param tuple i_origin:
        :rtype: None
        """
        return self.rendering_environment.PutOrigin(i_origin)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_origin'
        # # vba_code = """
        # # Public Function put_origin(rendering_environment)
        # #     Dim iOrigin (2)
        # #     rendering_environment.PutOrigin iOrigin
        # #     put_origin = iOrigin
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def put_vertical_axis(self, i_axis: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PutVerticalAxis(CATSafeArrayVariant iAxis)
                | 
                |     Sets the coordinates of the vertical axis vector of the
                |     environment.
                |     These coordinates are set as an array of 3 Variants (double type).

        :param tuple i_axis:
        :rtype: None
        """
        return self.rendering_environment.PutVerticalAxis(i_axis)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_vertical_axis'
        # # vba_code = """
        # # Public Function put_vertical_axis(rendering_environment)
        # #     Dim iAxis (2)
        # #     rendering_environment.PutVerticalAxis iAxis
        # #     put_vertical_axis = iAxis
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'RenderingEnvironment(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.manufacturing_interfaces.manufacturing_machinable_area import ManufacturingMachinableArea
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingSurfaceMachiningArea(ManufacturingMachinableArea):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                    ManufacturingInterfaces.ManufacturingFeature
                |                        ManufacturingInterfaces.ManufacturingMachinableFeature
                |                            ManufacturingInterfaces.ManufacturingMachinableArea
                |                                ManufacturingSurfaceMachiningArea
                | 
                | Represents the Manufacturing Surface Machining Area.
                | Role: Allows you to associate NCGeometries with a Machining
                | Area.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_surface_machining_area = com_object

    def remove_nc_geometry(self, i_geometry_type: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveNCGeometry(CATBSTR iGeometryType)
                | 
                |     Removes all the NCGeometry of a specified type linked to a Manufacturing
                |     Surface Machining Area.
                | 
                |     Parameters:
                | 
                |         iGeometryType
                |             Legal values: iGeometryType can be
                | 
                |             GuidingElements
                |                 to remove the limiting contour 
                |             Parts
                |                 to remove the part to machine 
                |             Checks
                |                 to remove the check elements 
                | 
                | 
                |         Example: The following example removes the part of the manufacturing
                |         surface machining area CurrentSMA
                | 
                |          Call CurrentSMA.RemoveNCGeometry("Parts")

        :param str i_geometry_type:
        :rtype: None
        """
        return self.manufacturing_surface_machining_area.RemoveNCGeometry(i_geometry_type)

    def set_nc_geometry(self, i_geometry_type: str, i_nc_geometry: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetNCGeometry(CATBSTR iGeometryType,
                | AnyObject iNCGeometry)
                | 
                |     Sets a NCGeometry of a specified type to a Manufacturing Surface Machining
                |     Area.
                | 
                |     Parameters:
                | 
                |         iGeometryType
                |             Legal values: iGeometryType can be
                | 
                |             GuidingElements
                |                 to set the limiting contour 
                |             Parts
                |                 to set the part to machine 
                |             Checks
                |                 to set a check element 
                | 
                |         iNCGeometry
                |             The NCGeometry to be set. 
                | 
                | 
                |         Example: The following example sets the NCGeometry NCGeomPart to the
                |         manufacturing surface machining area CurrentSMA
                | 
                |          Call CurrentSMA.SetNCGeometry("Parts",NCGeomPart)

        :param str i_geometry_type:
        :param AnyObject i_nc_geometry:
        :rtype: None
        """
        return self.manufacturing_surface_machining_area.SetNCGeometry(i_geometry_type, i_nc_geometry.com_object)

    def __repr__(self):
        return f'ManufacturingSurfaceMachiningArea(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class StrCutoutFeature(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     StrCutoutFeature
                | 
                | Represents a Cutout Feature.
                | CutoutType,Direction,Surface,DeirectionElement can be
                | redefined.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.str_cutout_feature = com_object

    @property
    def contour(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Contour() As Reference
                | 
                |     Returns or Sets the Contour Sketch for Current Cutout.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim NewContour As Reference
                |          Set NewContour = rootProduct.CreateReferenceFromName("Product1/New/!Sketch.2")
                |          ExistingCutout.Contour =NewContour

        :rtype: Reference
        """

        return Reference(self.str_cutout_feature.Contour)

    @contour.setter
    def contour(self, value: Reference):
        """
        :param Reference value:
        """

        self.str_cutout_feature.Contour = value.com_object

    @property
    def cutout_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CutoutType() As CATBSTR
                | 
                |     Returns or Sets the CutoutType for Current Cutout.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim Type As String
                |          Type = Cutout1.CutoutType

        :rtype: str
        """

        return self.str_cutout_feature.CutoutType

    @cutout_type.setter
    def cutout_type(self, value: str):
        """
        :param str value:
        """

        self.str_cutout_feature.CutoutType = value

    @property
    def direction(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Direction() As CATSafeArrayVariant
                | 
                |     Returns or Sets the Direction Vector for Current Cutout.If we are in
                |     CATStrBeforeForming mode, it gives NULL.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim GetDir(3)
                |          GetDir(3) = Cutoutctr.Direction
                |          Dim x, y, z As Double
                |          x = GetDir(0)
                |          y = GetDir(1)
                |          z = GetDir(2)
                |          'For Setting Direction
                |          Dim Setdir(3) 
                |          Setdir(0) = 0.5
                |          Setdir(1) = 0.5
                |          Setdir(2) = 0.5
                |          Cutout1.Direction =Setdir

        :rtype: tuple
        """

        return self.str_cutout_feature.Direction

    @direction.setter
    def direction(self, value: tuple):
        """
        :param tuple value:
        """

        self.str_cutout_feature.Direction = value

    @property
    def direction_element(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DirectionElement() As Reference
                | 
                |     Returns or Sets the Element used for defining for Current Cutout.If we are
                |     in CATStrBeforeForming mode, it gives NULL.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim DirOfCutOut As Reference
                |          Set DirOfCutOut = Cutout2.DirectionElement

        :rtype: Reference
        """

        return Reference(self.str_cutout_feature.DirectionElement)

    @direction_element.setter
    def direction_element(self, value: Reference):
        """
        :param Reference value:
        """

        self.str_cutout_feature.DirectionElement = value.com_object

    @property
    def reference_surface(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ReferenceSurface() As Reference
                | 
                |     Returns or Sets the Reference Surface used for defining for Current
                |     Cutout.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim SurForCutout As Reference
                |          Set SurForCutout = Cutout2.ReferenceSurface

        :rtype: Reference
        """

        return Reference(self.str_cutout_feature.ReferenceSurface)

    @reference_surface.setter
    def reference_surface(self, value: Reference):
        """
        :param Reference value:
        """

        self.str_cutout_feature.ReferenceSurface = value.com_object

    def get_object(self) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetObject() As Product
                | 
                |     Retrieves the Structure object on which the cutout is applied
                |     on.
                | 
                |     Parameters:
                | 
                |         oObject
                |             [out] Product 
                | 
                |     Returns:
                |         S_OK if everything ran ok.
                | 
                |         Example
                |         :
                |             This example gives the product on which cutout is
                |             applied.
                | 
                |              Dim Prod As Product
                |              Set Prod = Cutout1.GetObject
                |              
                | 
                |     Copyright © 1999-2011, Dassault Systèmes. All rights
                |     reserved.

        :rtype: Product
        """
        return Product(self.str_cutout_feature.GetObject())

    def __repr__(self):
        return f'StrCutoutFeature(name="{self.name}")'
